@@ -188,12 +188,12 @@ ValaCCodeExpression* vala_ccode_element_access_get_container (ValaCCodeElementAc
 
 
 void vala_ccode_element_access_set_container (ValaCCodeElementAccess* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2;
-	ValaCCodeExpression* _tmp1;
+	ValaCCodeExpression* _tmp2_;
+	ValaCCodeExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_container = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_container == NULL) ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_container = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_container == NULL) ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL)), _tmp2_);
 }
 
 
@@ -204,12 +204,12 @@ ValaCCodeExpression* vala_ccode_element_access_get_index (ValaCCodeElementAccess
 
 
 void vala_ccode_element_access_set_index (ValaCCodeElementAccess* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2;
-	ValaCCodeExpression* _tmp1;
+	ValaCCodeExpression* _tmp2_;
+	ValaCCodeExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_index = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_index == NULL) ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_index = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_index == NULL) ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL)), _tmp2_);
 }
 
 
