@@ -212,7 +212,7 @@ ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, Va
 
 static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeIfStatement * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	self = (ValaCCodeIfStatement*) base;
 	g_return_if_fail (writer != NULL);
 	if (!self->priv->_else_if) {
@@ -225,18 +225,18 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 		vala_ccode_node_write ((ValaCCodeNode*) self->priv->_condition, writer);
 	}
 	vala_ccode_writer_write_string (writer, ")");
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (self->priv->_false_statement != NULL) {
-		_tmp0 = VALA_IS_CCODE_BLOCK (self->priv->_true_statement);
+		_tmp0_ = VALA_IS_CCODE_BLOCK (self->priv->_true_statement);
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
 	/* else shouldn't be on a separate line */
-	if (_tmp0) {
-		ValaCCodeBlock* _tmp1;
+	if (_tmp0_) {
+		ValaCCodeBlock* _tmp1_;
 		ValaCCodeBlock* cblock;
-		_tmp1 = NULL;
-		cblock = (_tmp1 = VALA_CCODE_BLOCK (self->priv->_true_statement), (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1));
+		_tmp1_ = NULL;
+		cblock = (_tmp1_ = VALA_CCODE_BLOCK (self->priv->_true_statement), (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_));
 		vala_ccode_block_set_suppress_newline (cblock, TRUE);
 		(cblock == NULL) ? NULL : (cblock = (vala_ccode_node_unref (cblock), NULL));
 	}
@@ -250,10 +250,10 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 		}
 		/* else if should be on one line */
 		if (VALA_IS_CCODE_IF_STATEMENT (self->priv->_false_statement)) {
-			ValaCCodeIfStatement* _tmp2;
+			ValaCCodeIfStatement* _tmp2_;
 			ValaCCodeIfStatement* cif;
-			_tmp2 = NULL;
-			cif = (_tmp2 = VALA_CCODE_IF_STATEMENT (self->priv->_false_statement), (_tmp2 == NULL) ? NULL : vala_ccode_node_ref (_tmp2));
+			_tmp2_ = NULL;
+			cif = (_tmp2_ = VALA_CCODE_IF_STATEMENT (self->priv->_false_statement), (_tmp2_ == NULL) ? NULL : vala_ccode_node_ref (_tmp2_));
 			vala_ccode_if_statement_set_else_if (cif, TRUE);
 			(cif == NULL) ? NULL : (cif = (vala_ccode_node_unref (cif), NULL));
 		}
@@ -269,12 +269,12 @@ ValaCCodeExpression* vala_ccode_if_statement_get_condition (ValaCCodeIfStatement
 
 
 void vala_ccode_if_statement_set_condition (ValaCCodeIfStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2;
-	ValaCCodeExpression* _tmp1;
+	ValaCCodeExpression* _tmp2_;
+	ValaCCodeExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_condition = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp2_);
 }
 
 
@@ -285,12 +285,12 @@ ValaCCodeStatement* vala_ccode_if_statement_get_true_statement (ValaCCodeIfState
 
 
 void vala_ccode_if_statement_set_true_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
-	ValaCCodeStatement* _tmp2;
-	ValaCCodeStatement* _tmp1;
+	ValaCCodeStatement* _tmp2_;
+	ValaCCodeStatement* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_true_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_ccode_node_unref (self->priv->_true_statement), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_true_statement = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_ccode_node_unref (self->priv->_true_statement), NULL)), _tmp2_);
 }
 
 
@@ -301,12 +301,12 @@ ValaCCodeStatement* vala_ccode_if_statement_get_false_statement (ValaCCodeIfStat
 
 
 void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
-	ValaCCodeStatement* _tmp2;
-	ValaCCodeStatement* _tmp1;
+	ValaCCodeStatement* _tmp2_;
+	ValaCCodeStatement* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_false_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_ccode_node_unref (self->priv->_false_statement), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_false_statement = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_ccode_node_unref (self->priv->_false_statement), NULL)), _tmp2_);
 }
 
 
