@@ -175,12 +175,12 @@ ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self) {
 
 
 void vala_ccode_node_set_line (ValaCCodeNode* self, ValaCCodeLineDirective* value) {
-	ValaCCodeLineDirective* _tmp2;
-	ValaCCodeLineDirective* _tmp1;
+	ValaCCodeLineDirective* _tmp2_;
+	ValaCCodeLineDirective* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_line = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_line == NULL) ? NULL : (self->priv->_line = (vala_ccode_node_unref (self->priv->_line), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_line = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_line == NULL) ? NULL : (self->priv->_line = (vala_ccode_node_unref (self->priv->_line), NULL)), _tmp2_);
 }
 
 
