@@ -202,6 +202,16 @@ typedef struct _ValaValueTypeClass ValaValueTypeClass;
 typedef struct _ValaIntegerType ValaIntegerType;
 typedef struct _ValaIntegerTypeClass ValaIntegerTypeClass;
 
+#define VALA_TYPE_ENUM_VALUE_TYPE (vala_enum_value_type_get_type ())
+#define VALA_ENUM_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM_VALUE_TYPE, ValaEnumValueType))
+#define VALA_ENUM_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ENUM_VALUE_TYPE, ValaEnumValueTypeClass))
+#define VALA_IS_ENUM_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ENUM_VALUE_TYPE))
+#define VALA_IS_ENUM_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ENUM_VALUE_TYPE))
+#define VALA_ENUM_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ENUM_VALUE_TYPE, ValaEnumValueTypeClass))
+
+typedef struct _ValaEnumValueType ValaEnumValueType;
+typedef struct _ValaEnumValueTypeClass ValaEnumValueTypeClass;
+
 /**
  * Represents a part of the parsed source code.
  *
@@ -336,6 +346,7 @@ void vala_expression_set_target_type (ValaExpression* self, ValaDataType* value)
 ValaDataType* vala_expression_get_value_type (ValaExpression* self);
 GType vala_value_type_get_type (void);
 GType vala_integer_type_get_type (void);
+GType vala_enum_value_type_get_type (void);
 void vala_data_type_set_value_owned (ValaDataType* self, gboolean value);
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
@@ -517,9 +528,9 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 	ValaInitializerList* _tmp1_;
 	ValaInitializerList* initlist;
 	GeeArrayList* calc_sizes;
-	gboolean _tmp5_;
-	ValaArrayType* _tmp8_;
-	gboolean _tmp9_;
+	gboolean _tmp6_;
+	ValaArrayType* _tmp9_;
+	gboolean _tmp10_;
 	self = (ValaArrayCreationExpression*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -572,7 +583,14 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 					/* return on previous error */
 					return (_tmp3_ = FALSE, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL)), (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp3_);
 				} else {
-					if (!VALA_IS_INTEGER_TYPE (vala_expression_get_value_type (e))) {
+					gboolean _tmp4_;
+					_tmp4_ = FALSE;
+					if (VALA_IS_INTEGER_TYPE (vala_expression_get_value_type (e))) {
+						_tmp4_ = TRUE;
+					} else {
+						_tmp4_ = VALA_IS_ENUM_VALUE_TYPE (vala_expression_get_value_type (e));
+					}
+					if (!_tmp4_) {
 						vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 						vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), "Expression of integer type expected");
 					}
@@ -601,33 +619,33 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 		}
 	}
 	if (vala_code_node_get_error ((ValaCodeNode*) self)) {
-		gboolean _tmp4_;
-		return (_tmp4_ = FALSE, (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp4_);
+		gboolean _tmp5_;
+		return (_tmp5_ = FALSE, (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp5_);
 	}
-	_tmp5_ = FALSE;
+	_tmp6_ = FALSE;
 	if (vala_array_creation_expression_get_initializer_list (self) != NULL) {
-		_tmp5_ = vala_expression_get_value_type ((ValaExpression*) vala_array_creation_expression_get_initializer_list (self)) == NULL;
+		_tmp6_ = vala_expression_get_value_type ((ValaExpression*) vala_array_creation_expression_get_initializer_list (self)) == NULL;
 	} else {
-		_tmp5_ = FALSE;
+		_tmp6_ = FALSE;
 	}
 	/* check for wrong elements inside the initializer */
-	if (_tmp5_) {
-		gboolean _tmp6_;
-		return (_tmp6_ = FALSE, (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp6_);
+	if (_tmp6_) {
+		gboolean _tmp7_;
+		return (_tmp7_ = FALSE, (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp7_);
 	}
 	/* try to construct the type of the array */
 	if (vala_array_creation_expression_get_element_type (self) == NULL) {
-		gboolean _tmp7_;
+		gboolean _tmp8_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Cannot determine the element type of the created array");
-		return (_tmp7_ = FALSE, (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp7_);
+		return (_tmp8_ = FALSE, (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp8_);
 	}
 	vala_data_type_set_value_owned (vala_array_creation_expression_get_element_type (self), TRUE);
-	_tmp8_ = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp8_ = vala_array_type_new (vala_array_creation_expression_get_element_type (self), self->priv->_rank, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp8_ == NULL) ? NULL : (_tmp8_ = (vala_code_node_unref (_tmp8_), NULL));
+	_tmp9_ = NULL;
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp9_ = vala_array_type_new (vala_array_creation_expression_get_element_type (self), self->priv->_rank, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	(_tmp9_ == NULL) ? NULL : (_tmp9_ = (vala_code_node_unref (_tmp9_), NULL));
 	vala_data_type_set_value_owned (vala_expression_get_value_type ((ValaExpression*) self), TRUE);
-	return (_tmp9_ = !vala_code_node_get_error ((ValaCodeNode*) self), (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp9_);
+	return (_tmp10_ = !vala_code_node_get_error ((ValaCodeNode*) self), (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp10_);
 }
 
 
