@@ -329,7 +329,7 @@ static void vala_cast_expression_real_replace_type (ValaCodeNode* base, ValaData
 
 static gboolean vala_cast_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaCastExpression * self;
-	ValaDataType* _tmp2;
+	ValaDataType* _tmp2_;
 	self = (ValaCastExpression*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -344,9 +344,9 @@ static gboolean vala_cast_expression_real_check (ValaCodeNode* base, ValaSemanti
 	/* FIXME: check whether cast is allowed*/
 	vala_expression_set_value_type ((ValaExpression*) self, vala_cast_expression_get_type_reference (self));
 	vala_data_type_set_value_owned (vala_expression_get_value_type ((ValaExpression*) self), vala_data_type_get_value_owned (vala_expression_get_value_type (vala_cast_expression_get_inner (self))));
-	_tmp2 = NULL;
-	vala_expression_set_target_type (vala_cast_expression_get_inner (self), _tmp2 = vala_data_type_copy (vala_expression_get_value_type (vala_cast_expression_get_inner (self))));
-	(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
+	_tmp2_ = NULL;
+	vala_expression_set_target_type (vala_cast_expression_get_inner (self), _tmp2_ = vala_data_type_copy (vala_expression_get_value_type (vala_cast_expression_get_inner (self))));
+	(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
 	return !vala_code_node_get_error ((ValaCodeNode*) self);
 }
 
@@ -374,12 +374,12 @@ ValaExpression* vala_cast_expression_get_inner (ValaCastExpression* self) {
 
 
 void vala_cast_expression_set_inner (ValaCastExpression* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_inner = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_inner, (ValaCodeNode*) self);
 }
 
@@ -391,12 +391,12 @@ ValaDataType* vala_cast_expression_get_type_reference (ValaCastExpression* self)
 
 
 void vala_cast_expression_set_type_reference (ValaCastExpression* self, ValaDataType* value) {
-	ValaDataType* _tmp2;
-	ValaDataType* _tmp1;
+	ValaDataType* _tmp2_;
+	ValaDataType* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_data_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
