@@ -318,10 +318,11 @@ ValaSourceFile* vala_source_reference_get_file (ValaSourceReference* self);
 void vala_semantic_analyzer_set_current_source_file (ValaSemanticAnalyzer* self, ValaSourceFile* value);
 void vala_semantic_analyzer_set_current_symbol (ValaSemanticAnalyzer* self, ValaSymbol* value);
 gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
-gboolean vala_symbol_get_external_package (ValaSymbol* self);
+gboolean vala_symbol_get_external (ValaSymbol* self);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 void vala_report_error (ValaSourceReference* source, const char* message);
 void vala_expression_set_target_type (ValaExpression* self, ValaDataType* value);
+gboolean vala_symbol_get_external_package (ValaSymbol* self);
 gboolean vala_member_get_hides (ValaMember* self);
 ValaSymbol* vala_member_get_hidden_member (ValaMember* self);
 void vala_report_warning (ValaSourceReference* source, const char* message);
@@ -331,6 +332,7 @@ void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 static gpointer vala_constant_parent_class = NULL;
 static ValaLockableIface* vala_constant_vala_lockable_parent_iface = NULL;
 static void vala_constant_finalize (ValaCodeNode* obj);
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static gint _vala_array_length (gpointer array);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -388,15 +390,15 @@ static void vala_constant_real_accept_children (ValaCodeNode* base, ValaCodeVisi
  * @return the name to be used in C code
  */
 char* vala_constant_get_cname (ValaConstant* self) {
-	const char* _tmp1;
+	const char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->cname == NULL) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		self->priv->cname = (_tmp0 = vala_constant_get_default_cname (self), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0);
+		char* _tmp0_;
+		_tmp0_ = NULL;
+		self->priv->cname = (_tmp0_ = vala_constant_get_default_cname (self), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
 	}
-	_tmp1 = NULL;
-	return (_tmp1 = self->priv->cname, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1));
+	_tmp1_ = NULL;
+	return (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
 }
 
 
@@ -409,18 +411,18 @@ char* vala_constant_get_cname (ValaConstant* self) {
 char* vala_constant_get_default_cname (ValaConstant* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	if (vala_symbol_get_parent_symbol ((ValaSymbol*) self) == NULL) {
-		const char* _tmp0;
+		const char* _tmp0_;
 		/* global constant*/
-		_tmp0 = NULL;
-		return (_tmp0 = vala_symbol_get_name ((ValaSymbol*) self), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
+		_tmp0_ = NULL;
+		return (_tmp0_ = vala_symbol_get_name ((ValaSymbol*) self), (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
 	} else {
-		char* _tmp3;
-		char* _tmp2;
-		char* _tmp4;
-		_tmp3 = NULL;
-		_tmp2 = NULL;
-		_tmp4 = NULL;
-		return (_tmp4 = g_strdup_printf ("%s%s", _tmp3 = g_utf8_strup (_tmp2 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), -1), vala_symbol_get_name ((ValaSymbol*) self)), _tmp3 = (g_free (_tmp3), NULL), _tmp2 = (g_free (_tmp2), NULL), _tmp4);
+		char* _tmp3_;
+		char* _tmp2_;
+		char* _tmp4_;
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		_tmp4_ = NULL;
+		return (_tmp4_ = g_strdup_printf ("%s%s", _tmp3_ = g_utf8_strup (_tmp2_ = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), -1), vala_symbol_get_name ((ValaSymbol*) self)), _tmp3_ = (g_free (_tmp3_), NULL), _tmp2_ = (g_free (_tmp2_), NULL), _tmp4_);
 	}
 }
 
@@ -454,26 +456,26 @@ static void vala_constant_process_ccode_attribute (ValaConstant* self, ValaAttri
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (a != NULL);
 	if (vala_attribute_has_argument (a, "cname")) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		self->priv->cname = (_tmp0 = vala_attribute_get_string (a, "cname"), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0);
+		char* _tmp0_;
+		_tmp0_ = NULL;
+		self->priv->cname = (_tmp0_ = vala_attribute_get_string (a, "cname"), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
 		val = vala_attribute_get_string (a, "cheader_filename");
 		{
-			char** _tmp1;
+			char** _tmp1_;
 			char** filename_collection;
 			int filename_collection_length1;
 			int filename_it;
-			_tmp1 = NULL;
-			filename_collection = _tmp1 = g_strsplit (val, ",", 0);
-			filename_collection_length1 = _vala_array_length (_tmp1);
-			for (filename_it = 0; filename_it < _vala_array_length (_tmp1); filename_it = filename_it + 1) {
-				const char* _tmp2;
+			_tmp1_ = NULL;
+			filename_collection = _tmp1_ = g_strsplit (val, ",", 0);
+			filename_collection_length1 = _vala_array_length (_tmp1_);
+			for (filename_it = 0; filename_it < _vala_array_length (_tmp1_); filename_it = filename_it + 1) {
+				const char* _tmp2_;
 				char* filename;
-				_tmp2 = NULL;
-				filename = (_tmp2 = filename_collection[filename_it], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2));
+				_tmp2_ = NULL;
+				filename = (_tmp2_ = filename_collection[filename_it], (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
 				{
 					vala_member_add_cheader_filename ((ValaMember*) self, filename);
 					filename = (g_free (filename), NULL);
@@ -496,10 +498,10 @@ void vala_constant_process_attributes (ValaConstant* self) {
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp0;
+			ValaAttribute* _tmp0_;
 			ValaAttribute* a;
-			_tmp0 = NULL;
-			a = (_tmp0 = (ValaAttribute*) a_it->data, (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
+			_tmp0_ = NULL;
+			a = (_tmp0_ = (ValaAttribute*) a_it->data, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_constant_process_ccode_attribute (self, a);
@@ -513,13 +515,13 @@ void vala_constant_process_attributes (ValaConstant* self) {
 
 static gboolean vala_constant_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaConstant * self;
-	ValaSourceFile* _tmp1;
+	ValaSourceFile* _tmp1_;
 	ValaSourceFile* old_source_file;
-	ValaSymbol* _tmp2;
+	ValaSymbol* _tmp2_;
 	ValaSymbol* old_symbol;
-	gboolean _tmp3;
-	gboolean _tmp4;
-	gboolean _tmp10;
+	gboolean _tmp3_;
+	gboolean _tmp4_;
+	gboolean _tmp10_;
 	self = (ValaConstant*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -527,16 +529,16 @@ static gboolean vala_constant_real_check (ValaCodeNode* base, ValaSemanticAnalyz
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_constant_process_attributes (self);
-	_tmp1 = NULL;
-	old_source_file = (_tmp1 = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp1 == NULL) ? NULL : vala_source_file_ref (_tmp1));
-	_tmp2 = NULL;
-	old_symbol = (_tmp2 = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
+	_tmp1_ = NULL;
+	old_source_file = (_tmp1_ = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp1_ == NULL) ? NULL : vala_source_file_ref (_tmp1_));
+	_tmp2_ = NULL;
+	old_symbol = (_tmp2_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
 	if (vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL) {
 		vala_semantic_analyzer_set_current_source_file (analyzer, vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self)));
 	}
 	vala_semantic_analyzer_set_current_symbol (analyzer, (ValaSymbol*) self);
 	vala_code_node_check ((ValaCodeNode*) vala_constant_get_type_reference (self), analyzer);
-	if (!vala_symbol_get_external_package ((ValaSymbol*) self)) {
+	if (!vala_symbol_get_external ((ValaSymbol*) self)) {
 		if (vala_constant_get_initializer (self) == NULL) {
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "A const field requires a initializer to be provided");
@@ -545,39 +547,39 @@ static gboolean vala_constant_real_check (ValaCodeNode* base, ValaSemanticAnalyz
 			vala_code_node_check ((ValaCodeNode*) vala_constant_get_initializer (self), analyzer);
 		}
 	}
-	_tmp3 = FALSE;
-	_tmp4 = FALSE;
+	_tmp3_ = FALSE;
+	_tmp4_ = FALSE;
 	if (!vala_symbol_get_external_package ((ValaSymbol*) self)) {
-		_tmp4 = !vala_member_get_hides ((ValaMember*) self);
+		_tmp4_ = !vala_member_get_hides ((ValaMember*) self);
 	} else {
-		_tmp4 = FALSE;
+		_tmp4_ = FALSE;
 	}
-	if (_tmp4) {
-		ValaSymbol* _tmp5;
-		_tmp5 = NULL;
-		_tmp3 = (_tmp5 = vala_member_get_hidden_member ((ValaMember*) self)) != NULL;
-		(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL));
+	if (_tmp4_) {
+		ValaSymbol* _tmp5_;
+		_tmp5_ = NULL;
+		_tmp3_ = (_tmp5_ = vala_member_get_hidden_member ((ValaMember*) self)) != NULL;
+		(_tmp5_ == NULL) ? NULL : (_tmp5_ = (vala_code_node_unref (_tmp5_), NULL));
 	} else {
-		_tmp3 = FALSE;
+		_tmp3_ = FALSE;
 	}
-	if (_tmp3) {
-		char* _tmp9;
-		char* _tmp8;
-		ValaSymbol* _tmp7;
-		char* _tmp6;
-		_tmp9 = NULL;
-		_tmp8 = NULL;
-		_tmp7 = NULL;
-		_tmp6 = NULL;
-		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp9 = g_strdup_printf ("%s hides inherited constant `%s'. Use the `new' keyword if hiding was intentional", _tmp6 = vala_symbol_get_full_name ((ValaSymbol*) self), _tmp8 = vala_symbol_get_full_name (_tmp7 = vala_member_get_hidden_member ((ValaMember*) self))));
-		_tmp9 = (g_free (_tmp9), NULL);
-		_tmp8 = (g_free (_tmp8), NULL);
-		(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_code_node_unref (_tmp7), NULL));
-		_tmp6 = (g_free (_tmp6), NULL);
+	if (_tmp3_) {
+		char* _tmp9_;
+		char* _tmp8_;
+		ValaSymbol* _tmp7_;
+		char* _tmp6_;
+		_tmp9_ = NULL;
+		_tmp8_ = NULL;
+		_tmp7_ = NULL;
+		_tmp6_ = NULL;
+		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp9_ = g_strdup_printf ("%s hides inherited constant `%s'. Use the `new' keyword if hiding was intentional", _tmp6_ = vala_symbol_get_full_name ((ValaSymbol*) self), _tmp8_ = vala_symbol_get_full_name (_tmp7_ = vala_member_get_hidden_member ((ValaMember*) self))));
+		_tmp9_ = (g_free (_tmp9_), NULL);
+		_tmp8_ = (g_free (_tmp8_), NULL);
+		(_tmp7_ == NULL) ? NULL : (_tmp7_ = (vala_code_node_unref (_tmp7_), NULL));
+		_tmp6_ = (g_free (_tmp6_), NULL);
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	return (_tmp10 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp10);
+	return (_tmp10_ = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp10_);
 }
 
 
@@ -588,12 +590,12 @@ ValaDataType* vala_constant_get_type_reference (ValaConstant* self) {
 
 
 void vala_constant_set_type_reference (ValaConstant* self, ValaDataType* value) {
-	ValaDataType* _tmp2;
-	ValaDataType* _tmp1;
+	ValaDataType* _tmp2_;
+	ValaDataType* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_data_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
@@ -605,12 +607,12 @@ ValaExpression* vala_constant_get_initializer (ValaConstant* self) {
 
 
 void vala_constant_set_initializer (ValaConstant* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_initializer = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)), _tmp2_);
 	if (self->priv->_initializer != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_initializer, (ValaCodeNode*) self);
 	}
@@ -663,7 +665,7 @@ GType vala_constant_get_type (void) {
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
 		for (i = 0; i < array_length; i = i + 1) {
@@ -672,6 +674,11 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 			}
 		}
 	}
+}
+
+
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	_vala_array_destroy (array, array_length, destroy_func);
 	g_free (array);
 }
 
