@@ -299,14 +299,14 @@ static gboolean vala_delete_statement_real_check (ValaCodeNode* base, ValaSemant
 		return FALSE;
 	}
 	if (!VALA_IS_POINTER_TYPE (vala_expression_get_value_type (self->priv->_expression))) {
-		char* _tmp3;
-		char* _tmp2;
+		char* _tmp3_;
+		char* _tmp2_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		_tmp3 = NULL;
-		_tmp2 = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp3 = g_strdup_printf ("delete operator not supported for `%s'", _tmp2 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (self->priv->_expression))));
-		_tmp3 = (g_free (_tmp3), NULL);
-		_tmp2 = (g_free (_tmp2), NULL);
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp3_ = g_strdup_printf ("delete operator not supported for `%s'", _tmp2_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (self->priv->_expression))));
+		_tmp3_ = (g_free (_tmp3_), NULL);
+		_tmp2_ = (g_free (_tmp2_), NULL);
 	}
 	return !vala_code_node_get_error ((ValaCodeNode*) self);
 }
@@ -319,12 +319,12 @@ ValaExpression* vala_delete_statement_get_expression (ValaDeleteStatement* self)
 
 
 void vala_delete_statement_set_expression (ValaDeleteStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp2_);
 }
 
 
