@@ -1023,7 +1023,6 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* ulong_type;
 	ValaDataType* size_t_type;
 	ValaDataType* ssize_t_type;
-	ValaDataType* uint64_type;
 	ValaDataType* int8_type;
 	ValaDataType* unichar_type;
 	ValaDataType* double_type;
@@ -1296,8 +1295,8 @@ static void vala_do_statement_real_replace_expression (ValaCodeNode* base, ValaE
 
 static gboolean vala_do_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaDoStatement * self;
-	GeeList* _tmp3;
-	GeeList* _tmp4;
+	GeeList* _tmp3_;
+	GeeList* _tmp4_;
 	self = (ValaDoStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -1315,39 +1314,39 @@ static gboolean vala_do_statement_real_check (ValaCodeNode* base, ValaSemanticAn
 		return FALSE;
 	}
 	vala_code_node_check ((ValaCodeNode*) vala_do_statement_get_body (self), analyzer);
-	_tmp3 = NULL;
-	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp3 = vala_code_node_get_error_types ((ValaCodeNode*) vala_do_statement_get_condition (self)));
-	(_tmp3 == NULL) ? NULL : (_tmp3 = (gee_collection_object_unref (_tmp3), NULL));
-	_tmp4 = NULL;
-	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp4 = vala_code_node_get_error_types ((ValaCodeNode*) vala_do_statement_get_body (self)));
-	(_tmp4 == NULL) ? NULL : (_tmp4 = (gee_collection_object_unref (_tmp4), NULL));
+	_tmp3_ = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp3_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_do_statement_get_condition (self)));
+	(_tmp3_ == NULL) ? NULL : (_tmp3_ = (gee_collection_object_unref (_tmp3_), NULL));
+	_tmp4_ = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp4_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_do_statement_get_body (self)));
+	(_tmp4_ == NULL) ? NULL : (_tmp4_ = (gee_collection_object_unref (_tmp4_), NULL));
 	return !vala_code_node_get_error ((ValaCodeNode*) self);
 }
 
 
 ValaBlock* vala_do_statement_prepare_condition_split (ValaDoStatement* self, ValaSemanticAnalyzer* analyzer) {
-	ValaBooleanLiteral* _tmp2;
-	char* _tmp1;
-	ValaDataType* _tmp0;
-	ValaLocalVariable* _tmp3;
+	ValaBooleanLiteral* _tmp2_;
+	char* _tmp1_;
+	ValaDataType* _tmp0_;
+	ValaLocalVariable* _tmp3_;
 	ValaLocalVariable* first_local;
 	ValaDeclarationStatement* first_decl;
-	ValaBlock* _tmp4;
+	ValaBlock* _tmp4_;
 	ValaBlock* block;
 	ValaUnaryExpression* if_condition;
 	ValaBlock* true_block;
-	ValaBreakStatement* _tmp5;
+	ValaBreakStatement* _tmp5_;
 	ValaIfStatement* if_stmt;
 	ValaBlock* condition_block;
-	ValaMemberAccess* _tmp6;
-	ValaIfStatement* _tmp7;
+	ValaMemberAccess* _tmp6_;
+	ValaIfStatement* _tmp7_;
 	ValaIfStatement* first_if;
-	ValaExpressionStatement* _tmp11;
-	ValaAssignment* _tmp10;
-	ValaBooleanLiteral* _tmp9;
-	ValaMemberAccess* _tmp8;
-	ValaBooleanLiteral* _tmp12;
-	ValaBlock* _tmp13;
+	ValaExpressionStatement* _tmp11_;
+	ValaAssignment* _tmp10_;
+	ValaBooleanLiteral* _tmp9_;
+	ValaMemberAccess* _tmp8_;
+	ValaBooleanLiteral* _tmp12_;
+	ValaBlock* _tmp13_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (analyzer != NULL, NULL);
 	/* move condition into the loop body to allow split
@@ -1364,43 +1363,43 @@ ValaBlock* vala_do_statement_prepare_condition_split (ValaDoStatement* self, Val
 	 *     ...
 	 * } while (true);
 	 */
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	_tmp3 = NULL;
-	first_local = (_tmp3 = vala_local_variable_new (_tmp0 = vala_data_type_copy (analyzer->bool_type), _tmp1 = vala_code_node_get_temp_name ((ValaCodeNode*) self), (ValaExpression*) (_tmp2 = vala_boolean_literal_new (FALSE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self)), (_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL)), _tmp1 = (g_free (_tmp1), NULL), (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp3);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	_tmp3_ = NULL;
+	first_local = (_tmp3_ = vala_local_variable_new (_tmp0_ = vala_data_type_copy (analyzer->bool_type), _tmp1_ = vala_code_node_get_temp_name ((ValaCodeNode*) self), (ValaExpression*) (_tmp2_ = vala_boolean_literal_new (FALSE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self)), (_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL)), _tmp1_ = (g_free (_tmp1_), NULL), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL)), _tmp3_);
 	first_decl = vala_declaration_statement_new ((ValaSymbol*) first_local, vala_code_node_get_source_reference ((ValaCodeNode*) self));
 	vala_code_node_check ((ValaCodeNode*) first_decl, analyzer);
-	_tmp4 = NULL;
-	block = (_tmp4 = VALA_BLOCK (vala_semantic_analyzer_get_current_symbol (analyzer)), (_tmp4 == NULL) ? NULL : vala_code_node_ref (_tmp4));
+	_tmp4_ = NULL;
+	block = (_tmp4_ = VALA_BLOCK (vala_semantic_analyzer_get_current_symbol (analyzer)), (_tmp4_ == NULL) ? NULL : vala_code_node_ref (_tmp4_));
 	vala_block_insert_before (block, (ValaStatement*) self, (ValaStatement*) first_decl);
 	if_condition = vala_unary_expression_new (VALA_UNARY_OPERATOR_LOGICAL_NEGATION, vala_do_statement_get_condition (self), vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)));
 	true_block = vala_block_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)));
-	_tmp5 = NULL;
-	vala_block_add_statement (true_block, (ValaStatement*) (_tmp5 = vala_break_statement_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)))));
-	(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL));
+	_tmp5_ = NULL;
+	vala_block_add_statement (true_block, (ValaStatement*) (_tmp5_ = vala_break_statement_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)))));
+	(_tmp5_ == NULL) ? NULL : (_tmp5_ = (vala_code_node_unref (_tmp5_), NULL));
 	if_stmt = vala_if_statement_new ((ValaExpression*) if_condition, true_block, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)));
 	condition_block = vala_block_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)));
 	vala_block_add_statement (condition_block, (ValaStatement*) if_stmt);
-	_tmp6 = NULL;
-	_tmp7 = NULL;
-	first_if = (_tmp7 = vala_if_statement_new ((ValaExpression*) (_tmp6 = vala_member_access_new_simple (vala_symbol_get_name ((ValaSymbol*) first_local), vala_code_node_get_source_reference ((ValaCodeNode*) self))), condition_block, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self)), (_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL)), _tmp7);
+	_tmp6_ = NULL;
+	_tmp7_ = NULL;
+	first_if = (_tmp7_ = vala_if_statement_new ((ValaExpression*) (_tmp6_ = vala_member_access_new_simple (vala_symbol_get_name ((ValaSymbol*) first_local), vala_code_node_get_source_reference ((ValaCodeNode*) self))), condition_block, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self)), (_tmp6_ == NULL) ? NULL : (_tmp6_ = (vala_code_node_unref (_tmp6_), NULL)), _tmp7_);
 	vala_block_insert_statement (vala_do_statement_get_body (self), 0, (ValaStatement*) first_if);
-	_tmp11 = NULL;
-	_tmp10 = NULL;
-	_tmp9 = NULL;
-	_tmp8 = NULL;
-	vala_block_insert_statement (vala_do_statement_get_body (self), 1, (ValaStatement*) (_tmp11 = vala_expression_statement_new ((ValaExpression*) (_tmp10 = vala_assignment_new ((ValaExpression*) (_tmp8 = vala_member_access_new_simple (vala_symbol_get_name ((ValaSymbol*) first_local), vala_code_node_get_source_reference ((ValaCodeNode*) self))), (ValaExpression*) (_tmp9 = vala_boolean_literal_new (TRUE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), VALA_ASSIGNMENT_OPERATOR_SIMPLE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_code_node_unref (_tmp11), NULL));
-	(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_code_node_unref (_tmp10), NULL));
-	(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_code_node_unref (_tmp9), NULL));
-	(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_code_node_unref (_tmp8), NULL));
-	_tmp12 = NULL;
-	vala_do_statement_set_condition (self, (ValaExpression*) (_tmp12 = vala_boolean_literal_new (TRUE, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp12 == NULL) ? NULL : (_tmp12 = (vala_code_node_unref (_tmp12), NULL));
+	_tmp11_ = NULL;
+	_tmp10_ = NULL;
+	_tmp9_ = NULL;
+	_tmp8_ = NULL;
+	vala_block_insert_statement (vala_do_statement_get_body (self), 1, (ValaStatement*) (_tmp11_ = vala_expression_statement_new ((ValaExpression*) (_tmp10_ = vala_assignment_new ((ValaExpression*) (_tmp8_ = vala_member_access_new_simple (vala_symbol_get_name ((ValaSymbol*) first_local), vala_code_node_get_source_reference ((ValaCodeNode*) self))), (ValaExpression*) (_tmp9_ = vala_boolean_literal_new (TRUE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), VALA_ASSIGNMENT_OPERATOR_SIMPLE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	(_tmp11_ == NULL) ? NULL : (_tmp11_ = (vala_code_node_unref (_tmp11_), NULL));
+	(_tmp10_ == NULL) ? NULL : (_tmp10_ = (vala_code_node_unref (_tmp10_), NULL));
+	(_tmp9_ == NULL) ? NULL : (_tmp9_ = (vala_code_node_unref (_tmp9_), NULL));
+	(_tmp8_ == NULL) ? NULL : (_tmp8_ = (vala_code_node_unref (_tmp8_), NULL));
+	_tmp12_ = NULL;
+	vala_do_statement_set_condition (self, (ValaExpression*) (_tmp12_ = vala_boolean_literal_new (TRUE, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	(_tmp12_ == NULL) ? NULL : (_tmp12_ = (vala_code_node_unref (_tmp12_), NULL));
 	vala_code_node_check ((ValaCodeNode*) vala_do_statement_get_condition (self), analyzer);
-	_tmp13 = NULL;
-	return (_tmp13 = condition_block, (first_local == NULL) ? NULL : (first_local = (vala_code_node_unref (first_local), NULL)), (first_decl == NULL) ? NULL : (first_decl = (vala_code_node_unref (first_decl), NULL)), (block == NULL) ? NULL : (block = (vala_code_node_unref (block), NULL)), (if_condition == NULL) ? NULL : (if_condition = (vala_code_node_unref (if_condition), NULL)), (true_block == NULL) ? NULL : (true_block = (vala_code_node_unref (true_block), NULL)), (if_stmt == NULL) ? NULL : (if_stmt = (vala_code_node_unref (if_stmt), NULL)), (first_if == NULL) ? NULL : (first_if = (vala_code_node_unref (first_if), NULL)), _tmp13);
+	_tmp13_ = NULL;
+	return (_tmp13_ = condition_block, (first_local == NULL) ? NULL : (first_local = (vala_code_node_unref (first_local), NULL)), (first_decl == NULL) ? NULL : (first_decl = (vala_code_node_unref (first_decl), NULL)), (block == NULL) ? NULL : (block = (vala_code_node_unref (block), NULL)), (if_condition == NULL) ? NULL : (if_condition = (vala_code_node_unref (if_condition), NULL)), (true_block == NULL) ? NULL : (true_block = (vala_code_node_unref (true_block), NULL)), (if_stmt == NULL) ? NULL : (if_stmt = (vala_code_node_unref (if_stmt), NULL)), (first_if == NULL) ? NULL : (first_if = (vala_code_node_unref (first_if), NULL)), _tmp13_);
 }
 
 
@@ -1411,12 +1410,12 @@ ValaBlock* vala_do_statement_get_body (ValaDoStatement* self) {
 
 
 void vala_do_statement_set_body (ValaDoStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp2;
-	ValaBlock* _tmp1;
+	ValaBlock* _tmp2_;
+	ValaBlock* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_body = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_body, (ValaCodeNode*) self);
 }
 
@@ -1428,12 +1427,12 @@ ValaExpression* vala_do_statement_get_condition (ValaDoStatement* self) {
 
 
 void vala_do_statement_set_condition (ValaDoStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_condition = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_condition, (ValaCodeNode*) self);
 }
 
