@@ -219,6 +219,7 @@ struct _ValaDataType {
 struct _ValaDataTypeClass {
 	ValaCodeNodeClass parent_class;
 	char* (*get_cname) (ValaDataType* self);
+	char* (*get_cdeclarator_suffix) (ValaDataType* self);
 	char* (*get_lower_case_cname) (ValaDataType* self, const char* infix);
 	char* (*to_qualified_string) (ValaDataType* self, ValaScope* scope);
 	ValaDataType* (*copy) (ValaDataType* self);
@@ -335,13 +336,13 @@ ValaEnumValueType* vala_enum_value_type_new (ValaEnum* type_symbol) {
 
 static ValaDataType* vala_enum_value_type_real_copy (ValaDataType* base) {
 	ValaEnumValueType * self;
-	ValaEnumValueType* result;
+	ValaEnumValueType* _result_;
 	self = (ValaEnumValueType*) base;
-	result = vala_enum_value_type_new (VALA_ENUM (vala_value_type_get_type_symbol ((ValaValueType*) self)));
-	vala_code_node_set_source_reference ((ValaCodeNode*) result, vala_code_node_get_source_reference ((ValaCodeNode*) self));
-	vala_data_type_set_value_owned ((ValaDataType*) result, vala_data_type_get_value_owned ((ValaDataType*) self));
-	vala_data_type_set_nullable ((ValaDataType*) result, vala_data_type_get_nullable ((ValaDataType*) self));
-	return (ValaDataType*) result;
+	_result_ = vala_enum_value_type_new (VALA_ENUM (vala_value_type_get_type_symbol ((ValaValueType*) self)));
+	vala_code_node_set_source_reference ((ValaCodeNode*) _result_, vala_code_node_get_source_reference ((ValaCodeNode*) self));
+	vala_data_type_set_value_owned ((ValaDataType*) _result_, vala_data_type_get_value_owned ((ValaDataType*) self));
+	vala_data_type_set_nullable ((ValaDataType*) _result_, vala_data_type_get_nullable ((ValaDataType*) self));
+	return (ValaDataType*) _result_;
 }
 
 
