@@ -1036,7 +1036,6 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* ulong_type;
 	ValaDataType* size_t_type;
 	ValaDataType* ssize_t_type;
-	ValaDataType* uint64_type;
 	ValaDataType* int8_type;
 	ValaDataType* unichar_type;
 	ValaDataType* double_type;
@@ -1221,7 +1220,7 @@ static void vala_lock_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor
 
 static gboolean vala_lock_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaLockStatement * self;
-	gboolean _tmp1;
+	gboolean _tmp1_;
 	self = (ValaLockStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -1230,14 +1229,14 @@ static gboolean vala_lock_statement_real_check (ValaCodeNode* base, ValaSemantic
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_code_node_check ((ValaCodeNode*) self->priv->_resource, analyzer);
 	vala_code_node_check ((ValaCodeNode*) self->priv->_body, analyzer);
-	_tmp1 = FALSE;
+	_tmp1_ = FALSE;
 	if (VALA_IS_MEMBER_ACCESS (self->priv->_resource)) {
-		_tmp1 = VALA_IS_LOCKABLE (vala_expression_get_symbol_reference (self->priv->_resource));
+		_tmp1_ = VALA_IS_LOCKABLE (vala_expression_get_symbol_reference (self->priv->_resource));
 	} else {
-		_tmp1 = FALSE;
+		_tmp1_ = FALSE;
 	}
 	/* resource must be a member access and denote a Lockable */
-	if (!_tmp1) {
+	if (!_tmp1_) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_code_node_set_error ((ValaCodeNode*) self->priv->_resource, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self->priv->_resource), "Expression is either not a member access or does not denote a lockable member");
@@ -1261,12 +1260,12 @@ ValaExpression* vala_lock_statement_get_resource (ValaLockStatement* self) {
 
 
 void vala_lock_statement_set_resource (ValaLockStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_resource = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_resource == NULL) ? NULL : (self->priv->_resource = (vala_code_node_unref (self->priv->_resource), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_resource = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_resource == NULL) ? NULL : (self->priv->_resource = (vala_code_node_unref (self->priv->_resource), NULL)), _tmp2_);
 }
 
 
@@ -1277,12 +1276,12 @@ ValaBlock* vala_lock_statement_get_body (ValaLockStatement* self) {
 
 
 void vala_lock_statement_set_body (ValaLockStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp2;
-	ValaBlock* _tmp1;
+	ValaBlock* _tmp2_;
+	ValaBlock* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_body = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp2_);
 }
 
 
