@@ -325,16 +325,16 @@ static gboolean vala_null_literal_real_is_pure (ValaExpression* base) {
 
 static gboolean vala_null_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaNullLiteral * self;
-	ValaNullType* _tmp1;
+	ValaNullType* _tmp1_;
 	self = (ValaNullLiteral*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
 		return !vala_code_node_get_error ((ValaCodeNode*) self);
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	_tmp1 = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp1 = vala_null_type_new (vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL));
+	_tmp1_ = NULL;
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp1_ = vala_null_type_new (vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL));
 	return !vala_code_node_get_error ((ValaCodeNode*) self);
 }
 
