@@ -249,6 +249,7 @@ struct _ValaDataType {
 struct _ValaDataTypeClass {
 	ValaCodeNodeClass parent_class;
 	char* (*get_cname) (ValaDataType* self);
+	char* (*get_cdeclarator_suffix) (ValaDataType* self);
 	char* (*get_lower_case_cname) (ValaDataType* self, const char* infix);
 	char* (*to_qualified_string) (ValaDataType* self, ValaScope* scope);
 	ValaDataType* (*copy) (ValaDataType* self);
@@ -370,75 +371,75 @@ ValaNullType* vala_null_type_new (ValaSourceReference* source_reference) {
 
 static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaNullType * self;
-	gboolean _tmp0;
-	gboolean _tmp4;
-	gboolean _tmp5;
-	gboolean _tmp6;
-	gboolean _tmp9;
-	gboolean _tmp10;
+	gboolean _tmp0_;
+	gboolean _tmp4_;
+	gboolean _tmp5_;
+	gboolean _tmp6_;
+	gboolean _tmp9_;
+	gboolean _tmp10_;
 	self = (ValaNullType*) base;
 	g_return_val_if_fail (target_type != NULL, FALSE);
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (!VALA_IS_POINTER_TYPE (target_type)) {
-		gboolean _tmp1;
-		_tmp1 = FALSE;
+		gboolean _tmp1_;
+		_tmp1_ = FALSE;
 		if (VALA_IS_NULL_TYPE (target_type)) {
-			_tmp1 = TRUE;
+			_tmp1_ = TRUE;
 		} else {
-			gboolean _tmp2;
-			_tmp2 = FALSE;
+			gboolean _tmp2_;
+			_tmp2_ = FALSE;
 			if (vala_data_type_get_data_type (target_type) == NULL) {
-				_tmp2 = vala_data_type_get_type_parameter (target_type) == NULL;
+				_tmp2_ = vala_data_type_get_type_parameter (target_type) == NULL;
 			} else {
-				_tmp2 = FALSE;
+				_tmp2_ = FALSE;
 			}
-			_tmp1 = _tmp2;
+			_tmp1_ = _tmp2_;
 		}
-		_tmp0 = _tmp1;
+		_tmp0_ = _tmp1_;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	if (_tmp0) {
+	if (_tmp0_) {
 		return TRUE;
 	}
-	_tmp4 = FALSE;
-	_tmp5 = FALSE;
-	_tmp6 = FALSE;
+	_tmp4_ = FALSE;
+	_tmp5_ = FALSE;
+	_tmp6_ = FALSE;
 	if (vala_data_type_get_type_parameter (target_type) != NULL) {
-		_tmp6 = TRUE;
+		_tmp6_ = TRUE;
 	} else {
-		_tmp6 = VALA_IS_POINTER_TYPE (target_type);
+		_tmp6_ = VALA_IS_POINTER_TYPE (target_type);
 	}
-	if (_tmp6) {
-		_tmp5 = TRUE;
+	if (_tmp6_) {
+		_tmp5_ = TRUE;
 	} else {
-		_tmp5 = vala_data_type_get_nullable (target_type);
+		_tmp5_ = vala_data_type_get_nullable (target_type);
 	}
-	if (_tmp5) {
-		_tmp4 = TRUE;
+	if (_tmp5_) {
+		_tmp4_ = TRUE;
 	} else {
-		ValaAttribute* _tmp7;
-		_tmp7 = NULL;
-		_tmp4 = (_tmp7 = vala_code_node_get_attribute ((ValaCodeNode*) vala_data_type_get_data_type (target_type), "PointerType")) != NULL;
-		(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_code_node_unref (_tmp7), NULL));
+		ValaAttribute* _tmp7_;
+		_tmp7_ = NULL;
+		_tmp4_ = (_tmp7_ = vala_code_node_get_attribute ((ValaCodeNode*) vala_data_type_get_data_type (target_type), "PointerType")) != NULL;
+		(_tmp7_ == NULL) ? NULL : (_tmp7_ = (vala_code_node_unref (_tmp7_), NULL));
 	}
 	/* null can be cast to any reference or array type or pointer type */
-	if (_tmp4) {
+	if (_tmp4_) {
 		return TRUE;
 	}
-	_tmp9 = FALSE;
-	_tmp10 = FALSE;
+	_tmp9_ = FALSE;
+	_tmp10_ = FALSE;
 	if (vala_typesymbol_is_reference_type (vala_data_type_get_data_type (target_type))) {
-		_tmp10 = TRUE;
+		_tmp10_ = TRUE;
 	} else {
-		_tmp10 = VALA_IS_ARRAY_TYPE (target_type);
+		_tmp10_ = VALA_IS_ARRAY_TYPE (target_type);
 	}
-	if (_tmp10) {
-		_tmp9 = TRUE;
+	if (_tmp10_) {
+		_tmp9_ = TRUE;
 	} else {
-		_tmp9 = VALA_IS_DELEGATE_TYPE (target_type);
+		_tmp9_ = VALA_IS_DELEGATE_TYPE (target_type);
 	}
-	if (_tmp9) {
+	if (_tmp9_) {
 		return TRUE;
 	}
 	/* null is not compatible with any other type (i.e. value types) */
