@@ -249,6 +249,7 @@ struct _ValaDataType {
 struct _ValaDataTypeClass {
 	ValaCodeNodeClass parent_class;
 	char* (*get_cname) (ValaDataType* self);
+	char* (*get_cdeclarator_suffix) (ValaDataType* self);
 	char* (*get_lower_case_cname) (ValaDataType* self, const char* infix);
 	char* (*to_qualified_string) (ValaDataType* self, ValaScope* scope);
 	ValaDataType* (*copy) (ValaDataType* self);
@@ -395,103 +396,103 @@ ValaObjectType* vala_object_type_new (ValaObjectTypeSymbol* type_symbol) {
 
 static ValaDataType* vala_object_type_real_copy (ValaDataType* base) {
 	ValaObjectType * self;
-	ValaObjectType* result;
+	ValaObjectType* _result_;
 	self = (ValaObjectType*) base;
-	result = vala_object_type_new (self->priv->_type_symbol);
-	vala_code_node_set_source_reference ((ValaCodeNode*) result, vala_code_node_get_source_reference ((ValaCodeNode*) self));
-	vala_data_type_set_value_owned ((ValaDataType*) result, vala_data_type_get_value_owned ((ValaDataType*) self));
-	vala_data_type_set_nullable ((ValaDataType*) result, vala_data_type_get_nullable ((ValaDataType*) self));
-	vala_data_type_set_is_dynamic ((ValaDataType*) result, vala_data_type_get_is_dynamic ((ValaDataType*) self));
-	vala_data_type_set_floating_reference ((ValaDataType*) result, vala_data_type_get_floating_reference ((ValaDataType*) self));
+	_result_ = vala_object_type_new (self->priv->_type_symbol);
+	vala_code_node_set_source_reference ((ValaCodeNode*) _result_, vala_code_node_get_source_reference ((ValaCodeNode*) self));
+	vala_data_type_set_value_owned ((ValaDataType*) _result_, vala_data_type_get_value_owned ((ValaDataType*) self));
+	vala_data_type_set_nullable ((ValaDataType*) _result_, vala_data_type_get_nullable ((ValaDataType*) self));
+	vala_data_type_set_is_dynamic ((ValaDataType*) _result_, vala_data_type_get_is_dynamic ((ValaDataType*) self));
+	vala_data_type_set_floating_reference ((ValaDataType*) _result_, vala_data_type_get_floating_reference ((ValaDataType*) self));
 	{
-		GeeList* _tmp0;
-		GeeIterator* _tmp1;
+		GeeList* _tmp0_;
+		GeeIterator* _tmp1_;
 		GeeIterator* _arg_it;
-		_tmp0 = NULL;
-		_tmp1 = NULL;
-		_arg_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		_tmp0_ = NULL;
+		_tmp1_ = NULL;
+		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
 		while (gee_iterator_next (_arg_it)) {
 			ValaDataType* arg;
-			ValaDataType* _tmp2;
+			ValaDataType* _tmp2_;
 			arg = (ValaDataType*) gee_iterator_get (_arg_it);
-			_tmp2 = NULL;
-			vala_data_type_add_type_argument ((ValaDataType*) result, _tmp2 = vala_data_type_copy (arg));
-			(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
+			_tmp2_ = NULL;
+			vala_data_type_add_type_argument ((ValaDataType*) _result_, _tmp2_ = vala_data_type_copy (arg));
+			(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
 			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 		}
 		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 	}
-	return (ValaDataType*) result;
+	return (ValaDataType*) _result_;
 }
 
 
 static char* vala_object_type_real_get_cname (ValaDataType* base) {
 	ValaObjectType * self;
-	char* _tmp0;
-	char* _tmp1;
+	char* _tmp0_;
+	char* _tmp1_;
 	self = (ValaObjectType*) base;
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s*", _tmp0 = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_type_symbol, !vala_data_type_get_value_owned ((ValaDataType*) self))), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	return (_tmp1_ = g_strdup_printf ("%s*", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_type_symbol, !vala_data_type_get_value_owned ((ValaDataType*) self))), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
 }
 
 
 static gboolean vala_object_type_real_stricter (ValaDataType* base, ValaDataType* target_type) {
 	ValaObjectType * self;
-	ValaObjectType* _tmp1;
-	ValaDataType* _tmp0;
+	ValaObjectType* _tmp1_;
+	ValaDataType* _tmp0_;
 	ValaObjectType* obj_target_type;
-	gboolean _tmp4;
-	gboolean _tmp6;
+	gboolean _tmp4_;
+	gboolean _tmp6_;
 	self = (ValaObjectType*) base;
 	g_return_val_if_fail (target_type != NULL, FALSE);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	obj_target_type = (_tmp1 = (_tmp0 = target_type, VALA_IS_OBJECT_TYPE (_tmp0) ? ((ValaObjectType*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	obj_target_type = (_tmp1_ = (_tmp0_ = target_type, VALA_IS_OBJECT_TYPE (_tmp0_) ? ((ValaObjectType*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
 	if (obj_target_type == NULL) {
-		gboolean _tmp2;
-		return (_tmp2 = FALSE, (obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL)), _tmp2);
+		gboolean _tmp2_;
+		return (_tmp2_ = FALSE, (obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL)), _tmp2_);
 	}
 	if (vala_data_type_get_value_owned ((ValaDataType*) self) != vala_data_type_get_value_owned (target_type)) {
-		gboolean _tmp3;
-		return (_tmp3 = FALSE, (obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL)), _tmp3);
+		gboolean _tmp3_;
+		return (_tmp3_ = FALSE, (obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL)), _tmp3_);
 	}
-	_tmp4 = FALSE;
+	_tmp4_ = FALSE;
 	if (vala_data_type_get_nullable ((ValaDataType*) self)) {
-		_tmp4 = !vala_data_type_get_nullable (target_type);
+		_tmp4_ = !vala_data_type_get_nullable (target_type);
 	} else {
-		_tmp4 = FALSE;
+		_tmp4_ = FALSE;
 	}
-	if (_tmp4) {
-		gboolean _tmp5;
-		return (_tmp5 = FALSE, (obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL)), _tmp5);
+	if (_tmp4_) {
+		gboolean _tmp5_;
+		return (_tmp5_ = FALSE, (obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL)), _tmp5_);
 	}
-	return (_tmp6 = vala_typesymbol_is_subtype_of ((ValaTypeSymbol*) self->priv->_type_symbol, (ValaTypeSymbol*) obj_target_type->priv->_type_symbol), (obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL)), _tmp6);
+	return (_tmp6_ = vala_typesymbol_is_subtype_of ((ValaTypeSymbol*) self->priv->_type_symbol, (ValaTypeSymbol*) obj_target_type->priv->_type_symbol), (obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL)), _tmp6_);
 }
 
 
 static gboolean vala_object_type_real_is_invokable (ValaDataType* base) {
 	ValaObjectType * self;
-	ValaClass* _tmp1;
-	ValaObjectTypeSymbol* _tmp0;
+	ValaClass* _tmp1_;
+	ValaObjectTypeSymbol* _tmp0_;
 	ValaClass* cl;
-	gboolean _tmp2;
+	gboolean _tmp2_;
 	self = (ValaObjectType*) base;
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	cl = (_tmp1 = (_tmp0 = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
-	_tmp2 = FALSE;
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	cl = (_tmp1_ = (_tmp0_ = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0_) ? ((ValaClass*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+	_tmp2_ = FALSE;
 	if (cl != NULL) {
-		_tmp2 = vala_class_get_default_construction_method (cl) != NULL;
+		_tmp2_ = vala_class_get_default_construction_method (cl) != NULL;
 	} else {
-		_tmp2 = FALSE;
+		_tmp2_ = FALSE;
 	}
-	if (_tmp2) {
-		gboolean _tmp3;
-		return (_tmp3 = TRUE, (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp3);
+	if (_tmp2_) {
+		gboolean _tmp3_;
+		return (_tmp3_ = TRUE, (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp3_);
 	} else {
-		gboolean _tmp4;
-		return (_tmp4 = FALSE, (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp4);
+		gboolean _tmp4_;
+		return (_tmp4_ = FALSE, (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp4_);
 	}
 	(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
 }
@@ -499,30 +500,30 @@ static gboolean vala_object_type_real_is_invokable (ValaDataType* base) {
 
 static ValaDataType* vala_object_type_real_get_return_type (ValaDataType* base) {
 	ValaObjectType * self;
-	ValaClass* _tmp1;
-	ValaObjectTypeSymbol* _tmp0;
+	ValaClass* _tmp1_;
+	ValaObjectTypeSymbol* _tmp0_;
 	ValaClass* cl;
-	gboolean _tmp2;
+	gboolean _tmp2_;
 	self = (ValaObjectType*) base;
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	cl = (_tmp1 = (_tmp0 = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
-	_tmp2 = FALSE;
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	cl = (_tmp1_ = (_tmp0_ = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0_) ? ((ValaClass*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+	_tmp2_ = FALSE;
 	if (cl != NULL) {
-		_tmp2 = vala_class_get_default_construction_method (cl) != NULL;
+		_tmp2_ = vala_class_get_default_construction_method (cl) != NULL;
 	} else {
-		_tmp2 = FALSE;
+		_tmp2_ = FALSE;
 	}
-	if (_tmp2) {
-		ValaDataType* _tmp3;
-		ValaDataType* _tmp4;
-		_tmp3 = NULL;
-		_tmp4 = NULL;
-		return (_tmp4 = (_tmp3 = vala_method_get_return_type (vala_class_get_default_construction_method (cl)), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3)), (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp4);
+	if (_tmp2_) {
+		ValaDataType* _tmp3_;
+		ValaDataType* _tmp4_;
+		_tmp3_ = NULL;
+		_tmp4_ = NULL;
+		return (_tmp4_ = (_tmp3_ = vala_method_get_return_type (vala_class_get_default_construction_method (cl)), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_)), (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp4_);
 	} else {
-		ValaDataType* _tmp5;
-		_tmp5 = NULL;
-		return (_tmp5 = NULL, (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp5);
+		ValaDataType* _tmp5_;
+		_tmp5_ = NULL;
+		return (_tmp5_ = NULL, (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp5_);
 	}
 	(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
 }
@@ -530,28 +531,28 @@ static ValaDataType* vala_object_type_real_get_return_type (ValaDataType* base)
 
 static GeeList* vala_object_type_real_get_parameters (ValaDataType* base) {
 	ValaObjectType * self;
-	ValaClass* _tmp1;
-	ValaObjectTypeSymbol* _tmp0;
+	ValaClass* _tmp1_;
+	ValaObjectTypeSymbol* _tmp0_;
 	ValaClass* cl;
-	gboolean _tmp2;
+	gboolean _tmp2_;
 	self = (ValaObjectType*) base;
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	cl = (_tmp1 = (_tmp0 = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
-	_tmp2 = FALSE;
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	cl = (_tmp1_ = (_tmp0_ = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0_) ? ((ValaClass*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+	_tmp2_ = FALSE;
 	if (cl != NULL) {
-		_tmp2 = vala_class_get_default_construction_method (cl) != NULL;
+		_tmp2_ = vala_class_get_default_construction_method (cl) != NULL;
 	} else {
-		_tmp2 = FALSE;
+		_tmp2_ = FALSE;
 	}
-	if (_tmp2) {
-		GeeList* _tmp3;
-		_tmp3 = NULL;
-		return (_tmp3 = vala_method_get_parameters (vala_class_get_default_construction_method (cl)), (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp3);
+	if (_tmp2_) {
+		GeeList* _tmp3_;
+		_tmp3_ = NULL;
+		return (_tmp3_ = vala_method_get_parameters (vala_class_get_default_construction_method (cl)), (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp3_);
 	} else {
-		GeeList* _tmp4;
-		_tmp4 = NULL;
-		return (_tmp4 = NULL, (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp4);
+		GeeList* _tmp4_;
+		_tmp4_ = NULL;
+		return (_tmp4_ = NULL, (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp4_);
 	}
 	(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
 }
