@@ -122,13 +122,13 @@ static void vala_phi_function_finalize (ValaPhiFunction* obj);
 
 ValaPhiFunction* vala_phi_function_construct (GType object_type, ValaLocalVariable* variable, gint num_of_ops) {
 	ValaPhiFunction* self;
-	GeeArrayList* _tmp0;
+	GeeArrayList* _tmp0_;
 	g_return_val_if_fail (variable != NULL, NULL);
 	self = (ValaPhiFunction*) g_type_create_instance (object_type);
 	vala_phi_function_set_original_variable (self, variable);
-	_tmp0 = NULL;
-	vala_phi_function_set_operands (self, (GeeList*) (_tmp0 = gee_array_list_new (VALA_TYPE_LOCAL_VARIABLE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal)));
-	(_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL));
+	_tmp0_ = NULL;
+	vala_phi_function_set_operands (self, (GeeList*) (_tmp0_ = gee_array_list_new (VALA_TYPE_LOCAL_VARIABLE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal)));
+	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL));
 	{
 		gint i;
 		i = 0;
@@ -152,12 +152,12 @@ ValaLocalVariable* vala_phi_function_get_original_variable (ValaPhiFunction* sel
 
 
 static void vala_phi_function_set_original_variable (ValaPhiFunction* self, ValaLocalVariable* value) {
-	ValaLocalVariable* _tmp2;
-	ValaLocalVariable* _tmp1;
+	ValaLocalVariable* _tmp2_;
+	ValaLocalVariable* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_original_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_original_variable == NULL) ? NULL : (self->priv->_original_variable = (vala_code_node_unref (self->priv->_original_variable), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_original_variable = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_original_variable == NULL) ? NULL : (self->priv->_original_variable = (vala_code_node_unref (self->priv->_original_variable), NULL)), _tmp2_);
 }
 
 
@@ -168,12 +168,12 @@ GeeList* vala_phi_function_get_operands (ValaPhiFunction* self) {
 
 
 static void vala_phi_function_set_operands (ValaPhiFunction* self, GeeList* value) {
-	GeeList* _tmp2;
-	GeeList* _tmp1;
+	GeeList* _tmp2_;
+	GeeList* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_operands = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : gee_collection_object_ref (_tmp1)), (self->priv->_operands == NULL) ? NULL : (self->priv->_operands = (gee_collection_object_unref (self->priv->_operands), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_operands = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : gee_collection_object_ref (_tmp1_)), (self->priv->_operands == NULL) ? NULL : (self->priv->_operands = (gee_collection_object_unref (self->priv->_operands), NULL)), _tmp2_);
 }
 
 
