@@ -347,9 +347,9 @@ static gboolean vala_reference_transfer_expression_real_is_pure (ValaExpression*
 
 static gboolean vala_reference_transfer_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaReferenceTransferExpression * self;
-	gboolean _tmp2;
-	gboolean _tmp4;
-	ValaDataType* _tmp6;
+	gboolean _tmp2_;
+	gboolean _tmp4_;
+	ValaDataType* _tmp6_;
 	self = (ValaReferenceTransferExpression*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -363,31 +363,31 @@ static gboolean vala_reference_transfer_expression_real_check (ValaCodeNode* bas
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		return FALSE;
 	}
-	_tmp2 = FALSE;
+	_tmp2_ = FALSE;
 	if (VALA_IS_MEMBER_ACCESS (vala_reference_transfer_expression_get_inner (self))) {
-		_tmp2 = TRUE;
+		_tmp2_ = TRUE;
 	} else {
-		_tmp2 = VALA_IS_ELEMENT_ACCESS (vala_reference_transfer_expression_get_inner (self));
+		_tmp2_ = VALA_IS_ELEMENT_ACCESS (vala_reference_transfer_expression_get_inner (self));
 	}
-	if (!_tmp2) {
+	if (!_tmp2_) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Reference transfer not supported for this expression");
 		return FALSE;
 	}
-	_tmp4 = FALSE;
+	_tmp4_ = FALSE;
 	if (!vala_data_type_is_disposable (vala_expression_get_value_type (vala_reference_transfer_expression_get_inner (self)))) {
-		_tmp4 = !VALA_IS_POINTER_TYPE (vala_expression_get_value_type (vala_reference_transfer_expression_get_inner (self)));
+		_tmp4_ = !VALA_IS_POINTER_TYPE (vala_expression_get_value_type (vala_reference_transfer_expression_get_inner (self)));
 	} else {
-		_tmp4 = FALSE;
+		_tmp4_ = FALSE;
 	}
-	if (_tmp4) {
+	if (_tmp4_) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "No reference to be transferred");
 		return FALSE;
 	}
-	_tmp6 = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, _tmp6 = vala_data_type_copy (vala_expression_get_value_type (vala_reference_transfer_expression_get_inner (self))));
-	(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
+	_tmp6_ = NULL;
+	vala_expression_set_value_type ((ValaExpression*) self, _tmp6_ = vala_data_type_copy (vala_expression_get_value_type (vala_reference_transfer_expression_get_inner (self))));
+	(_tmp6_ == NULL) ? NULL : (_tmp6_ = (vala_code_node_unref (_tmp6_), NULL));
 	vala_data_type_set_value_owned (vala_expression_get_value_type ((ValaExpression*) self), TRUE);
 	return !vala_code_node_get_error ((ValaCodeNode*) self);
 }
@@ -416,12 +416,12 @@ ValaExpression* vala_reference_transfer_expression_get_inner (ValaReferenceTrans
 
 
 void vala_reference_transfer_expression_set_inner (ValaReferenceTransferExpression* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_inner = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_inner, (ValaCodeNode*) self);
 }
 
