@@ -1028,7 +1028,6 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* ulong_type;
 	ValaDataType* size_t_type;
 	ValaDataType* ssize_t_type;
-	ValaDataType* uint64_type;
 	ValaDataType* int8_type;
 	ValaDataType* unichar_type;
 	ValaDataType* double_type;
@@ -1252,16 +1251,16 @@ static void vala_return_statement_real_replace_expression (ValaCodeNode* base, V
 
 static gboolean vala_return_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaReturnStatement * self;
-	gboolean _tmp1;
-	gboolean _tmp11;
-	ValaLocalVariable* _tmp14;
-	ValaSymbol* _tmp13;
+	gboolean _tmp1_;
+	gboolean _tmp11_;
+	ValaLocalVariable* _tmp14_;
+	ValaSymbol* _tmp13_;
 	ValaLocalVariable* local;
-	gboolean _tmp15;
-	gboolean _tmp16;
-	gboolean _tmp18;
-	GeeList* _tmp21;
-	gboolean _tmp22;
+	gboolean _tmp15_;
+	gboolean _tmp16_;
+	gboolean _tmp18_;
+	GeeList* _tmp21_;
+	gboolean _tmp22_;
 	self = (ValaReturnStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -1271,13 +1270,13 @@ static gboolean vala_return_statement_real_check (ValaCodeNode* base, ValaSemant
 	if (vala_return_statement_get_return_expression (self) != NULL) {
 		vala_expression_set_target_type (vala_return_statement_get_return_expression (self), analyzer->current_return_type);
 	}
-	_tmp1 = FALSE;
+	_tmp1_ = FALSE;
 	if (vala_return_statement_get_return_expression (self) != NULL) {
-		_tmp1 = !vala_code_node_check ((ValaCodeNode*) vala_return_statement_get_return_expression (self), analyzer);
+		_tmp1_ = !vala_code_node_check ((ValaCodeNode*) vala_return_statement_get_return_expression (self), analyzer);
 	} else {
-		_tmp1 = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp1) {
+	if (_tmp1_) {
 		/* ignore inner error*/
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		return FALSE;
@@ -1304,70 +1303,70 @@ static gboolean vala_return_statement_real_check (ValaCodeNode* base, ValaSemant
 		return FALSE;
 	}
 	if (!vala_data_type_compatible (vala_expression_get_value_type (vala_return_statement_get_return_expression (self)), analyzer->current_return_type)) {
-		char* _tmp9;
-		char* _tmp8;
-		char* _tmp7;
+		char* _tmp9_;
+		char* _tmp8_;
+		char* _tmp7_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		_tmp9 = NULL;
-		_tmp8 = NULL;
-		_tmp7 = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp9 = g_strdup_printf ("Return: Cannot convert from `%s' to `%s'", _tmp7 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_return_statement_get_return_expression (self))), _tmp8 = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
-		_tmp9 = (g_free (_tmp9), NULL);
-		_tmp8 = (g_free (_tmp8), NULL);
-		_tmp7 = (g_free (_tmp7), NULL);
+		_tmp9_ = NULL;
+		_tmp8_ = NULL;
+		_tmp7_ = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp9_ = g_strdup_printf ("Return: Cannot convert from `%s' to `%s'", _tmp7_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_return_statement_get_return_expression (self))), _tmp8_ = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
+		_tmp9_ = (g_free (_tmp9_), NULL);
+		_tmp8_ = (g_free (_tmp8_), NULL);
+		_tmp7_ = (g_free (_tmp7_), NULL);
 		return FALSE;
 	}
-	_tmp11 = FALSE;
+	_tmp11_ = FALSE;
 	if (vala_data_type_is_disposable (vala_expression_get_value_type (vala_return_statement_get_return_expression (self)))) {
-		_tmp11 = !vala_data_type_get_value_owned (analyzer->current_return_type);
+		_tmp11_ = !vala_data_type_get_value_owned (analyzer->current_return_type);
 	} else {
-		_tmp11 = FALSE;
+		_tmp11_ = FALSE;
 	}
-	if (_tmp11) {
+	if (_tmp11_) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Return value transfers ownership but method return type hasn't been declared to transfer ownership");
 		return FALSE;
 	}
-	_tmp14 = NULL;
-	_tmp13 = NULL;
-	local = (_tmp14 = (_tmp13 = vala_expression_get_symbol_reference (vala_return_statement_get_return_expression (self)), VALA_IS_LOCAL_VARIABLE (_tmp13) ? ((ValaLocalVariable*) _tmp13) : NULL), (_tmp14 == NULL) ? NULL : vala_code_node_ref (_tmp14));
-	_tmp15 = FALSE;
-	_tmp16 = FALSE;
+	_tmp14_ = NULL;
+	_tmp13_ = NULL;
+	local = (_tmp14_ = (_tmp13_ = vala_expression_get_symbol_reference (vala_return_statement_get_return_expression (self)), VALA_IS_LOCAL_VARIABLE (_tmp13_) ? ((ValaLocalVariable*) _tmp13_) : NULL), (_tmp14_ == NULL) ? NULL : vala_code_node_ref (_tmp14_));
+	_tmp15_ = FALSE;
+	_tmp16_ = FALSE;
 	if (local != NULL) {
-		_tmp16 = vala_data_type_is_disposable (vala_local_variable_get_variable_type (local));
+		_tmp16_ = vala_data_type_is_disposable (vala_local_variable_get_variable_type (local));
 	} else {
-		_tmp16 = FALSE;
+		_tmp16_ = FALSE;
 	}
-	if (_tmp16) {
-		_tmp15 = !vala_data_type_get_value_owned (analyzer->current_return_type);
+	if (_tmp16_) {
+		_tmp15_ = !vala_data_type_get_value_owned (analyzer->current_return_type);
 	} else {
-		_tmp15 = FALSE;
+		_tmp15_ = FALSE;
 	}
-	if (_tmp15) {
-		gboolean _tmp17;
+	if (_tmp15_) {
+		gboolean _tmp17_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Local variable with strong reference used as return value and method return type has not been declared to transfer ownership");
-		return (_tmp17 = FALSE, (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp17);
+		return (_tmp17_ = FALSE, (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp17_);
 	}
-	_tmp18 = FALSE;
+	_tmp18_ = FALSE;
 	if (VALA_IS_NULL_LITERAL (vala_return_statement_get_return_expression (self))) {
-		_tmp18 = !vala_data_type_get_nullable (analyzer->current_return_type);
+		_tmp18_ = !vala_data_type_get_nullable (analyzer->current_return_type);
 	} else {
-		_tmp18 = FALSE;
+		_tmp18_ = FALSE;
 	}
-	if (_tmp18) {
-		char* _tmp20;
-		char* _tmp19;
-		_tmp20 = NULL;
-		_tmp19 = NULL;
-		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp20 = g_strdup_printf ("`null' incompatible with return type `%s`", _tmp19 = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
-		_tmp20 = (g_free (_tmp20), NULL);
-		_tmp19 = (g_free (_tmp19), NULL);
+	if (_tmp18_) {
+		char* _tmp20_;
+		char* _tmp19_;
+		_tmp20_ = NULL;
+		_tmp19_ = NULL;
+		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp20_ = g_strdup_printf ("`null' incompatible with return type `%s`", _tmp19_ = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
+		_tmp20_ = (g_free (_tmp20_), NULL);
+		_tmp19_ = (g_free (_tmp19_), NULL);
 	}
-	_tmp21 = NULL;
-	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp21 = vala_code_node_get_error_types ((ValaCodeNode*) vala_return_statement_get_return_expression (self)));
-	(_tmp21 == NULL) ? NULL : (_tmp21 = (gee_collection_object_unref (_tmp21), NULL));
-	return (_tmp22 = !vala_code_node_get_error ((ValaCodeNode*) self), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp22);
+	_tmp21_ = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp21_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_return_statement_get_return_expression (self)));
+	(_tmp21_ == NULL) ? NULL : (_tmp21_ = (gee_collection_object_unref (_tmp21_), NULL));
+	return (_tmp22_ = !vala_code_node_get_error ((ValaCodeNode*) self), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp22_);
 }
 
 
@@ -1398,12 +1397,12 @@ ValaExpression* vala_return_statement_get_return_expression (ValaReturnStatement
 
 
 void vala_return_statement_set_return_expression (ValaReturnStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_return_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_return_expression == NULL) ? NULL : (self->priv->_return_expression = (vala_code_node_unref (self->priv->_return_expression), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_return_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_return_expression == NULL) ? NULL : (self->priv->_return_expression = (vala_code_node_unref (self->priv->_return_expression), NULL)), _tmp2_);
 	if (self->priv->_return_expression != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_return_expression, (ValaCodeNode*) self);
 	}
