@@ -183,12 +183,12 @@ ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _fi
  * @return human-readable string
  */
 char* vala_source_reference_to_string (ValaSourceReference* self) {
-	char* _tmp0;
-	char* _tmp1;
+	char* _tmp0_;
+	char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s:%d.%d-%d.%d", _tmp0 = vala_source_file_get_relative_filename (self->priv->_file), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	return (_tmp1_ = g_strdup_printf ("%s:%d.%d-%d.%d", _tmp0_ = vala_source_file_get_relative_filename (self->priv->_file), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
 }
 
 
@@ -259,12 +259,12 @@ const char* vala_source_reference_get_comment (ValaSourceReference* self) {
 
 
 void vala_source_reference_set_comment (ValaSourceReference* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_comment = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_comment = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp2_);
 }
 
 
