@@ -219,6 +219,7 @@ struct _ValaDataType {
 struct _ValaDataTypeClass {
 	ValaCodeNodeClass parent_class;
 	char* (*get_cname) (ValaDataType* self);
+	char* (*get_cdeclarator_suffix) (ValaDataType* self);
 	char* (*get_lower_case_cname) (ValaDataType* self, const char* infix);
 	char* (*to_qualified_string) (ValaDataType* self, ValaScope* scope);
 	ValaDataType* (*copy) (ValaDataType* self);
@@ -338,31 +339,31 @@ ValaStructValueType* vala_struct_value_type_new (ValaStruct* type_symbol) {
 
 static ValaDataType* vala_struct_value_type_real_copy (ValaDataType* base) {
 	ValaStructValueType * self;
-	ValaStructValueType* result;
+	ValaStructValueType* _result_;
 	self = (ValaStructValueType*) base;
-	result = vala_struct_value_type_new (VALA_STRUCT (vala_value_type_get_type_symbol ((ValaValueType*) self)));
-	vala_code_node_set_source_reference ((ValaCodeNode*) result, vala_code_node_get_source_reference ((ValaCodeNode*) self));
-	vala_data_type_set_value_owned ((ValaDataType*) result, vala_data_type_get_value_owned ((ValaDataType*) self));
-	vala_data_type_set_nullable ((ValaDataType*) result, vala_data_type_get_nullable ((ValaDataType*) self));
+	_result_ = vala_struct_value_type_new (VALA_STRUCT (vala_value_type_get_type_symbol ((ValaValueType*) self)));
+	vala_code_node_set_source_reference ((ValaCodeNode*) _result_, vala_code_node_get_source_reference ((ValaCodeNode*) self));
+	vala_data_type_set_value_owned ((ValaDataType*) _result_, vala_data_type_get_value_owned ((ValaDataType*) self));
+	vala_data_type_set_nullable ((ValaDataType*) _result_, vala_data_type_get_nullable ((ValaDataType*) self));
 	{
-		GeeList* _tmp0;
-		GeeIterator* _tmp1;
+		GeeList* _tmp0_;
+		GeeIterator* _tmp1_;
 		GeeIterator* _arg_it;
-		_tmp0 = NULL;
-		_tmp1 = NULL;
-		_arg_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		_tmp0_ = NULL;
+		_tmp1_ = NULL;
+		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
 		while (gee_iterator_next (_arg_it)) {
 			ValaDataType* arg;
-			ValaDataType* _tmp2;
+			ValaDataType* _tmp2_;
 			arg = (ValaDataType*) gee_iterator_get (_arg_it);
-			_tmp2 = NULL;
-			vala_data_type_add_type_argument ((ValaDataType*) result, _tmp2 = vala_data_type_copy (arg));
-			(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
+			_tmp2_ = NULL;
+			vala_data_type_add_type_argument ((ValaDataType*) _result_, _tmp2_ = vala_data_type_copy (arg));
+			(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
 			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 		}
 		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 	}
-	return (ValaDataType*) result;
+	return (ValaDataType*) _result_;
 }
 
 
