@@ -633,27 +633,27 @@ char* vala_typesymbol_get_default_value (ValaTypeSymbol* self) {
 
 static GeeList* vala_typesymbol_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaTypeSymbol * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	self = (ValaTypeSymbol*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (gee_collection_get_size ((GeeCollection*) self->priv->cheader_filenames) == 0) {
-		_tmp0 = vala_symbol_get_parent_symbol ((ValaSymbol*) self) != NULL;
+		_tmp0_ = vala_symbol_get_parent_symbol ((ValaSymbol*) self) != NULL;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
 	/* parent_symbol can be null on incremental parsing*/
-	if (_tmp0) {
-		gboolean _tmp3;
-		gboolean _tmp4;
+	if (_tmp0_) {
+		gboolean _tmp3_;
+		gboolean _tmp4_;
 		/* default to header filenames of the namespace */
 		{
-			GeeList* _tmp1;
-			GeeIterator* _tmp2;
+			GeeList* _tmp1_;
+			GeeIterator* _tmp2_;
 			GeeIterator* _filename_it;
 			/* default to header filenames of the namespace */
-			_tmp1 = NULL;
-			_tmp2 = NULL;
-			_filename_it = (_tmp2 = gee_iterable_iterator ((GeeIterable*) (_tmp1 = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol ((ValaSymbol*) self)))), (_tmp1 == NULL) ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL)), _tmp2);
+			_tmp1_ = NULL;
+			_tmp2_ = NULL;
+			_filename_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol ((ValaSymbol*) self)))), (_tmp1_ == NULL) ? NULL : (_tmp1_ = (gee_collection_object_unref (_tmp1_), NULL)), _tmp2_);
 			/* default to header filenames of the namespace */
 			while (gee_iterator_next (_filename_it)) {
 				char* filename;
@@ -664,24 +664,24 @@ static GeeList* vala_typesymbol_real_get_cheader_filenames (ValaSymbol* base) {
 			}
 			(_filename_it == NULL) ? NULL : (_filename_it = (gee_collection_object_unref (_filename_it), NULL));
 		}
-		_tmp3 = FALSE;
-		_tmp4 = FALSE;
+		_tmp3_ = FALSE;
+		_tmp4_ = FALSE;
 		if (gee_collection_get_size ((GeeCollection*) self->priv->cheader_filenames) == 0) {
-			_tmp4 = vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL;
+			_tmp4_ = vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL;
 		} else {
-			_tmp4 = FALSE;
+			_tmp4_ = FALSE;
 		}
-		if (_tmp4) {
-			_tmp3 = !vala_symbol_get_external_package ((ValaSymbol*) self);
+		if (_tmp4_) {
+			_tmp3_ = !vala_symbol_get_external_package ((ValaSymbol*) self);
 		} else {
-			_tmp3 = FALSE;
+			_tmp3_ = FALSE;
 		}
-		if (_tmp3) {
-			char* _tmp5;
+		if (_tmp3_) {
+			char* _tmp5_;
 			/* don't add default include directives for VAPI files*/
-			_tmp5 = NULL;
-			gee_collection_add ((GeeCollection*) self->priv->cheader_filenames, _tmp5 = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-			_tmp5 = (g_free (_tmp5), NULL);
+			_tmp5_ = NULL;
+			gee_collection_add ((GeeCollection*) self->priv->cheader_filenames, _tmp5_ = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+			_tmp5_ = (g_free (_tmp5_), NULL);
 		}
 	}
 	return (GeeList*) gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->cheader_filenames);
