@@ -98,6 +98,8 @@ const char* vala_markup_reader_get_name (ValaMarkupReader* self);
 static GObject * vala_markup_reader_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_markup_reader_parent_class = NULL;
 static void vala_markup_reader_finalize (GObject* obj);
+static void vala_markup_reader_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
+static void vala_markup_reader_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
 const char* vala_markup_token_type_to_string (ValaMarkupTokenType self);
 
 
@@ -140,29 +142,29 @@ static char* vala_markup_reader_read_name (ValaMarkupReader* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	begin = self->priv->current;
 	while (self->priv->current < self->priv->end) {
-		gboolean _tmp0;
-		gboolean _tmp1;
-		gboolean _tmp2;
+		gboolean _tmp0_;
+		gboolean _tmp1_;
+		gboolean _tmp2_;
 		gunichar u;
-		_tmp0 = FALSE;
-		_tmp1 = FALSE;
-		_tmp2 = FALSE;
+		_tmp0_ = FALSE;
+		_tmp1_ = FALSE;
+		_tmp2_ = FALSE;
 		if (self->priv->current[0] == ' ') {
-			_tmp2 = TRUE;
+			_tmp2_ = TRUE;
 		} else {
-			_tmp2 = self->priv->current[0] == '>';
+			_tmp2_ = self->priv->current[0] == '>';
 		}
-		if (_tmp2) {
-			_tmp1 = TRUE;
+		if (_tmp2_) {
+			_tmp1_ = TRUE;
 		} else {
-			_tmp1 = self->priv->current[0] == '/';
+			_tmp1_ = self->priv->current[0] == '/';
 		}
-		if (_tmp1) {
-			_tmp0 = TRUE;
+		if (_tmp1_) {
+			_tmp0_ = TRUE;
 		} else {
-			_tmp0 = self->priv->current[0] == '=';
+			_tmp0_ = self->priv->current[0] == '=';
 		}
-		if (_tmp0) {
+		if (_tmp0_) {
 			break;
 		}
 		u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
@@ -204,41 +206,41 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 				if (self->priv->current[0] == '?') {
 				} else {
 					if (self->priv->current[0] == '!') {
-						gboolean _tmp1;
-						gboolean _tmp2;
+						gboolean _tmp1_;
+						gboolean _tmp2_;
 						/* comment or doctype*/
 						self->priv->current++;
-						_tmp1 = FALSE;
-						_tmp2 = FALSE;
+						_tmp1_ = FALSE;
+						_tmp2_ = FALSE;
 						if (self->priv->current < (self->priv->end - 1)) {
-							_tmp2 = self->priv->current[0] == '-';
+							_tmp2_ = self->priv->current[0] == '-';
 						} else {
-							_tmp2 = FALSE;
+							_tmp2_ = FALSE;
 						}
-						if (_tmp2) {
-							_tmp1 = self->priv->current[1] == '-';
+						if (_tmp2_) {
+							_tmp1_ = self->priv->current[1] == '-';
 						} else {
-							_tmp1 = FALSE;
+							_tmp1_ = FALSE;
 						}
-						if (_tmp1) {
+						if (_tmp1_) {
 							/* comment*/
 							self->priv->current = self->priv->current + 2;
 							while (self->priv->current < (self->priv->end - 2)) {
-								gboolean _tmp3;
-								gboolean _tmp4;
-								_tmp3 = FALSE;
-								_tmp4 = FALSE;
+								gboolean _tmp3_;
+								gboolean _tmp4_;
+								_tmp3_ = FALSE;
+								_tmp4_ = FALSE;
 								if (self->priv->current[0] == '-') {
-									_tmp4 = self->priv->current[1] == '-';
+									_tmp4_ = self->priv->current[1] == '-';
 								} else {
-									_tmp4 = FALSE;
+									_tmp4_ = FALSE;
 								}
-								if (_tmp4) {
-									_tmp3 = self->priv->current[2] == '>';
+								if (_tmp4_) {
+									_tmp3_ = self->priv->current[2] == '>';
 								} else {
-									_tmp3 = FALSE;
+									_tmp3_ = FALSE;
 								}
-								if (_tmp3) {
+								if (_tmp3_) {
 									/* end of comment*/
 									self->priv->current = self->priv->current + 3;
 									break;
@@ -250,88 +252,88 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 						}
 					} else {
 						if (self->priv->current[0] == '/') {
-							char* _tmp6;
-							gboolean _tmp7;
+							char* _tmp6_;
+							gboolean _tmp7_;
 							type = VALA_MARKUP_TOKEN_TYPE_END_ELEMENT;
 							self->priv->current++;
-							_tmp6 = NULL;
-							vala_markup_reader_set_name (self, _tmp6 = vala_markup_reader_read_name (self));
-							_tmp6 = (g_free (_tmp6), NULL);
-							_tmp7 = FALSE;
+							_tmp6_ = NULL;
+							vala_markup_reader_set_name (self, _tmp6_ = vala_markup_reader_read_name (self));
+							_tmp6_ = (g_free (_tmp6_), NULL);
+							_tmp7_ = FALSE;
 							if (self->priv->current >= self->priv->end) {
-								_tmp7 = TRUE;
+								_tmp7_ = TRUE;
 							} else {
-								_tmp7 = self->priv->current[0] != '>';
+								_tmp7_ = self->priv->current[0] != '>';
 							}
-							if (_tmp7) {
+							if (_tmp7_) {
 							}
 							/* error*/
 							self->priv->current++;
 						} else {
-							char* _tmp8;
-							gboolean _tmp15;
+							char* _tmp8_;
+							gboolean _tmp15_;
 							type = VALA_MARKUP_TOKEN_TYPE_START_ELEMENT;
-							_tmp8 = NULL;
-							vala_markup_reader_set_name (self, _tmp8 = vala_markup_reader_read_name (self));
-							_tmp8 = (g_free (_tmp8), NULL);
+							_tmp8_ = NULL;
+							vala_markup_reader_set_name (self, _tmp8_ = vala_markup_reader_read_name (self));
+							_tmp8_ = (g_free (_tmp8_), NULL);
 							vala_markup_reader_space (self);
 							while (TRUE) {
-								gboolean _tmp9;
-								gboolean _tmp10;
+								gboolean _tmp9_;
+								gboolean _tmp10_;
 								char* attr_name;
-								gboolean _tmp11;
-								gboolean _tmp12;
+								gboolean _tmp11_;
+								gboolean _tmp12_;
 								gchar* attr_begin;
 								char* attr_value;
-								gboolean _tmp14;
-								_tmp9 = FALSE;
-								_tmp10 = FALSE;
+								gboolean _tmp14_;
+								_tmp9_ = FALSE;
+								_tmp10_ = FALSE;
 								if (self->priv->current < self->priv->end) {
-									_tmp10 = self->priv->current[0] != '>';
+									_tmp10_ = self->priv->current[0] != '>';
 								} else {
-									_tmp10 = FALSE;
+									_tmp10_ = FALSE;
 								}
-								if (_tmp10) {
-									_tmp9 = self->priv->current[0] != '/';
+								if (_tmp10_) {
+									_tmp9_ = self->priv->current[0] != '/';
 								} else {
-									_tmp9 = FALSE;
+									_tmp9_ = FALSE;
 								}
-								if (!_tmp9) {
+								if (!_tmp9_) {
 									break;
 								}
 								attr_name = vala_markup_reader_read_name (self);
-								_tmp11 = FALSE;
+								_tmp11_ = FALSE;
 								if (self->priv->current >= self->priv->end) {
-									_tmp11 = TRUE;
+									_tmp11_ = TRUE;
 								} else {
-									_tmp11 = self->priv->current[0] != '=';
+									_tmp11_ = self->priv->current[0] != '=';
 								}
-								if (_tmp11) {
+								if (_tmp11_) {
 								}
 								/* error*/
 								self->priv->current++;
-								_tmp12 = FALSE;
+								_tmp12_ = FALSE;
 								if (self->priv->current >= self->priv->end) {
-									_tmp12 = TRUE;
+									_tmp12_ = TRUE;
 								} else {
-									_tmp12 = self->priv->current[0] != '"';
+									_tmp12_ = self->priv->current[0] != '"';
 								}
 								/* FIXME allow single quotes*/
-								if (_tmp12) {
+								if (_tmp12_) {
 								}
 								/* error*/
 								self->priv->current++;
 								attr_begin = self->priv->current;
 								while (TRUE) {
-									gboolean _tmp13;
+									gboolean _tmp13_;
 									gunichar u;
-									_tmp13 = FALSE;
+									_tmp13_ = FALSE;
 									if (self->priv->current < self->priv->end) {
-										_tmp13 = self->priv->current[0] != '"';
+										_tmp13_ = self->priv->current[0] != '"';
 									} else {
-										_tmp13 = FALSE;
+										_tmp13_ = FALSE;
 									}
-									if (!_tmp13) {
+									if (!_tmp13_) {
 										break;
 									}
 									u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
@@ -343,13 +345,13 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 								}
 								/* TODO process &amp; &gt; &lt; &quot; &apos;*/
 								attr_value = g_strndup ((const char*) attr_begin, self->priv->current - attr_begin);
-								_tmp14 = FALSE;
+								_tmp14_ = FALSE;
 								if (self->priv->current >= self->priv->end) {
-									_tmp14 = TRUE;
+									_tmp14_ = TRUE;
 								} else {
-									_tmp14 = self->priv->current[0] != '"';
+									_tmp14_ = self->priv->current[0] != '"';
 								}
-								if (_tmp14) {
+								if (_tmp14_) {
 								}
 								/* error*/
 								self->priv->current++;
@@ -365,13 +367,13 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 							} else {
 								self->priv->empty_element = FALSE;
 							}
-							_tmp15 = FALSE;
+							_tmp15_ = FALSE;
 							if (self->priv->current >= self->priv->end) {
-								_tmp15 = TRUE;
+								_tmp15_ = TRUE;
 							} else {
-								_tmp15 = self->priv->current[0] != '>';
+								_tmp15_ = self->priv->current[0] != '>';
 							}
-							if (_tmp15) {
+							if (_tmp15_) {
 							}
 							/* error*/
 							self->priv->current++;
@@ -384,15 +386,15 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 			vala_markup_reader_space (self);
 			text_begin = self->priv->current;
 			while (TRUE) {
-				gboolean _tmp16;
+				gboolean _tmp16_;
 				gunichar u;
-				_tmp16 = FALSE;
+				_tmp16_ = FALSE;
 				if (self->priv->current < self->priv->end) {
-					_tmp16 = self->priv->current[0] != '<';
+					_tmp16_ = self->priv->current[0] != '<';
 				} else {
-					_tmp16 = FALSE;
+					_tmp16_ = FALSE;
 				}
-				if (!_tmp16) {
+				if (!_tmp16_) {
 					break;
 				}
 				u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
@@ -423,14 +425,14 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 static void vala_markup_reader_space (ValaMarkupReader* self) {
 	g_return_if_fail (self != NULL);
 	while (TRUE) {
-		gboolean _tmp0;
-		_tmp0 = FALSE;
+		gboolean _tmp0_;
+		_tmp0_ = FALSE;
 		if (self->priv->current < self->priv->end) {
-			_tmp0 = g_ascii_isspace (self->priv->current[0]);
+			_tmp0_ = g_ascii_isspace (self->priv->current[0]);
 		} else {
-			_tmp0 = FALSE;
+			_tmp0_ = FALSE;
 		}
-		if (!_tmp0) {
+		if (!_tmp0_) {
 			break;
 		}
 		if (self->priv->current[0] == '\n') {
@@ -450,12 +452,12 @@ const char* vala_markup_reader_get_filename (ValaMarkupReader* self) {
 
 
 static void vala_markup_reader_set_filename (ValaMarkupReader* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_filename = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2_);
 	g_object_notify ((GObject *) self, "filename");
 }
 
@@ -467,12 +469,12 @@ const char* vala_markup_reader_get_name (ValaMarkupReader* self) {
 
 
 static void vala_markup_reader_set_name (ValaMarkupReader* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2_);
 	g_object_notify ((GObject *) self, "name");
 }
 
@@ -482,19 +484,19 @@ static GObject * vala_markup_reader_constructor (GType type, guint n_construct_p
 	ValaMarkupReaderClass * klass;
 	GObjectClass * parent_class;
 	ValaMarkupReader * self;
-	GError * inner_error;
+	GError * _inner_error_;
 	klass = VALA_MARKUP_READER_CLASS (g_type_class_peek (VALA_TYPE_MARKUP_READER));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
 	self = VALA_MARKUP_READER (obj);
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	{
 		{
-			GMappedFile* _tmp0;
-			_tmp0 = NULL;
-			self->priv->mapped_file = (_tmp0 = g_mapped_file_new (self->priv->_filename, FALSE, &inner_error), (self->priv->mapped_file == NULL) ? NULL : (self->priv->mapped_file = (g_mapped_file_free (self->priv->mapped_file), NULL)), _tmp0);
-			if (inner_error != NULL) {
-				if (inner_error->domain == G_FILE_ERROR) {
+			GMappedFile* _tmp0_;
+			_tmp0_ = NULL;
+			self->priv->mapped_file = (_tmp0_ = g_mapped_file_new (self->priv->_filename, FALSE, &_inner_error_), (self->priv->mapped_file == NULL) ? NULL : (self->priv->mapped_file = (g_mapped_file_free (self->priv->mapped_file), NULL)), _tmp0_);
+			if (_inner_error_ != NULL) {
+				if (_inner_error_->domain == G_FILE_ERROR) {
 					goto __catch3_g_file_error;
 				}
 				goto __finally3;
@@ -509,61 +511,26 @@ static GObject * vala_markup_reader_constructor (GType type, guint n_construct_p
 		__catch3_g_file_error:
 		{
 			GError * e;
-			e = inner_error;
-			inner_error = NULL;
+			e = _inner_error_;
+			_inner_error_ = NULL;
 			{
-				char* _tmp1;
-				_tmp1 = NULL;
-				vala_report_error (NULL, _tmp1 = g_strdup_printf ("Unable to map file `%s': %s", self->priv->_filename, e->message));
-				_tmp1 = (g_free (_tmp1), NULL);
+				char* _tmp1_;
+				_tmp1_ = NULL;
+				vala_report_error (NULL, _tmp1_ = g_strdup_printf ("Unable to map file `%s': %s", self->priv->_filename, e->message));
+				_tmp1_ = (g_free (_tmp1_), NULL);
 				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 			}
 		}
 		__finally3:
-		if (inner_error != NULL) {
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+		if (_inner_error_ != NULL) {
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+			g_clear_error (&_inner_error_);
 		}
 	}
 	return obj;
 }
 
 
-static void vala_markup_reader_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaMarkupReader * self;
-	gpointer boxed;
-	self = VALA_MARKUP_READER (object);
-	switch (property_id) {
-		case VALA_MARKUP_READER_FILENAME:
-		g_value_set_string (value, vala_markup_reader_get_filename (self));
-		break;
-		case VALA_MARKUP_READER_NAME:
-		g_value_set_string (value, vala_markup_reader_get_name (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_markup_reader_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaMarkupReader * self;
-	self = VALA_MARKUP_READER (object);
-	switch (property_id) {
-		case VALA_MARKUP_READER_FILENAME:
-		vala_markup_reader_set_filename (self, g_value_get_string (value));
-		break;
-		case VALA_MARKUP_READER_NAME:
-		vala_markup_reader_set_name (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_markup_reader_class_init (ValaMarkupReaderClass * klass) {
 	vala_markup_reader_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaMarkupReaderPrivate));
@@ -603,6 +570,41 @@ GType vala_markup_reader_get_type (void) {
 }
 
 
+static void vala_markup_reader_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
+	ValaMarkupReader * self;
+	gpointer boxed;
+	self = VALA_MARKUP_READER (object);
+	switch (property_id) {
+		case VALA_MARKUP_READER_FILENAME:
+		g_value_set_string (value, vala_markup_reader_get_filename (self));
+		break;
+		case VALA_MARKUP_READER_NAME:
+		g_value_set_string (value, vala_markup_reader_get_name (self));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
+static void vala_markup_reader_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
+	ValaMarkupReader * self;
+	self = VALA_MARKUP_READER (object);
+	switch (property_id) {
+		case VALA_MARKUP_READER_FILENAME:
+		vala_markup_reader_set_filename (self, g_value_get_string (value));
+		break;
+		case VALA_MARKUP_READER_NAME:
+		vala_markup_reader_set_name (self, g_value_get_string (value));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 const char* vala_markup_token_type_to_string (ValaMarkupTokenType self) {
 	switch (self) {
 		case VALA_MARKUP_TOKEN_TYPE_START_ELEMENT:
